summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_object.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /khtml/rendering/render_object.cpp
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'khtml/rendering/render_object.cpp')
-rw-r--r--khtml/rendering/render_object.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/khtml/rendering/render_object.cpp b/khtml/rendering/render_object.cpp
index 1fc72c7d8..162ca4956 100644
--- a/khtml/rendering/render_object.cpp
+++ b/khtml/rendering/render_object.cpp
@@ -535,9 +535,9 @@ bool RenderObject::hasStaticY() const
void RenderObject::setPixmap(const TQPixmap&, const TQRect& /*r*/, CachedImage* image)
{
//tqrepaint bg when it finished loading
if(image && parent() && style() && style()->backgroundLayers()->containsImage(image)) {
- isBody() ? canvas()->tqrepaint() : tqrepaint();
+ isBody() ? canvas()->repaint() : repaint();
}
}
@@ -1164,15 +1164,15 @@ TQString RenderObject::information() const
<< " mB: " << marginBottom() << " qB: " << isBottomMarginQuirk()
<< "}"
<< (isTableCell() ?
- ( TQString::tqfromLatin1(" [r=") +
+ ( TQString::fromLatin1(" [r=") +
TQString::number( static_cast<const RenderTableCell *>(this)->row() ) +
- TQString::tqfromLatin1(" c=") +
+ TQString::fromLatin1(" c=") +
TQString::number( static_cast<const RenderTableCell *>(this)->col() ) +
- TQString::tqfromLatin1(" rs=") +
+ TQString::fromLatin1(" rs=") +
TQString::number( static_cast<const RenderTableCell *>(this)->rowSpan() ) +
- TQString::tqfromLatin1(" cs=") +
+ TQString::fromLatin1(" cs=") +
TQString::number( static_cast<const RenderTableCell *>(this)->colSpan() ) +
- TQString::tqfromLatin1("]") ) : TQString::null );
+ TQString::fromLatin1("]") ) : TQString::null );
if ( layer() )
ts << " layer=" << layer();
if ( continuation() )
@@ -1283,11 +1283,11 @@ void RenderObject::setStyle(RenderStyle *style)
m_style->outlineWidth() > style->outlineWidth() ||
(!m_style->hidesOverflow() && style->hidesOverflow()) ||
( m_style->hasClip() && !(m_style->clip() == style->clip()) ) ) ) {
// schedule a tqrepaint with the old style
if (layer() && !isInlineFlow())
- layer()->tqrepaint(pri);
+ layer()->repaint(pri);
else
- tqrepaint(pri);
+ repaint(pri);
}
if ( ( isFloating() && m_style->floating() != style->floating() ) ||
@@ -1345,7 +1345,7 @@ void RenderObject::setStyle(RenderStyle *style)
}
setNeedsLayoutAndMinMaxRecalc();
} else if (!isText() && d >= RenderStyle::Visible) {
// a tqrepaint is enough
if (layer()) {
if (canvas() && canvas()->needsWidgetMasks()) {
// update our widget masks
@@ -1357,9 +1357,9 @@ void RenderObject::setStyle(RenderStyle *style)
}
}
if (layer() && !isInlineFlow())
- layer()->tqrepaint(pri);
+ layer()->repaint(pri);
else
- tqrepaint(pri);
+ repaint(pri);
}
}
}
@@ -1428,9 +1428,9 @@ void RenderObject::repaintDuringLayout()
if (canvas()->needsFullRepaint() || isText())
return;
if (layer() && !isInlineFlow()) {
- layer()->tqrepaint( NormalPriority, true );
+ layer()->repaint( NormalPriority, true );
} else {
- tqrepaint();
+ repaint();
canvas()->deferredRepaint( this );
}
}
@@ -1850,7 +1850,7 @@ short RenderObject::getVerticalPosition( bool firstLine, RenderObject* ref ) con
bool checkParent = ref->isInline() && !ref->isReplacedBlock() &&
!( ref->style()->verticalAlign() == TOP || ref->style()->verticalAlign() == BOTTOM );
vpos = checkParent ? ref->verticalPositionHint( firstLine ) : 0;
- // don't allow elements nested inside text-top to have a different vtqalignment.
+ // don't allow elements nested inside text-top to have a different valignment.
if ( va == BASELINE )
return vpos;
else if ( va == LENGTH )
@@ -535,9 +535,9 @@ bool RenderObject::hasStaticY() const
void RenderObject::setPixmap(const TQPixmap&, const TQRect& /*r*/, CachedImage* image)
{
- //tqrepaint bg when it finished loading
+ //repaint bg when it finished loading
if(image && parent() && style() && style()->backgroundLayers()->containsImage(image)) {
@@ -1283,11 +1283,11 @@ void RenderObject::setStyle(RenderStyle *style)
(!m_style->hidesOverflow() && style->hidesOverflow()) ||
( m_style->hasClip() && !(m_style->clip() == style->clip()) ) ) ) {
- // schedule a tqrepaint with the old style
+ // schedule a repaint with the old style
if (layer() && !isInlineFlow())
@@ -1345,7 +1345,7 @@ void RenderObject::setStyle(RenderStyle *style)
setNeedsLayoutAndMinMaxRecalc();
} else if (!isText() && d >= RenderStyle::Visible) {
- // a tqrepaint is enough
+ // a repaint is enough
if (layer()) {
if (canvas() && canvas()->needsWidgetMasks()) {